@@ -1,8 +1,8 @@
 #' Check if an argument is a list
 #'
 #' @note
-#' Contrary to R's \code{\link[base]{is.list}}, objects of type \code{\link[base]{pairlist}} are not
-#' recognized as list.
+#' Contrary to R's \code{\link[base]{is.list}}, objects of type \code{\link[base]{data.frame}}
+#' and \code{\link[base]{pairlist}} are not recognized as list.
 #'
 #' Missingness is defined here as elements of the list being \code{NULL}, analogously to \code{\link{anyMissing}}.
 #'
@@ -13,8 +13,6 @@
 #' @templateVar fn List
 #' @template x
 #' @inheritParams checkVector
-#' @param ... [any]\cr
-#'  Additional parameters used in a call of \code{\link{checkVector}}.
 #' @param types [\code{character}]\cr
 #'  Character vector of class names. Each list element must inherit
 #'  from at least one of the provided types.
@@ -57,7 +55,7 @@ checkListTypes = function(x, types = character(0L)) {
     if (length(ind) == 0L)
       return(TRUE)
   }
-  return(sprintf("May only contain the following types: %s", paste0(types, collapse = ",")))
+  sprintf("May only contain the following types: {%s}, but element %i has type '%s'", paste0(types, collapse = ","), ind[1L], paste0(class(x[[ind[1L]]]), collapse = ","))
 }
 
 #' @export
